package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.cryptopro.CryptoProObjectIdentifiers;
import cn.com.infosec.asn1.cryptopro.ECGOST3410NamedCurves;
import cn.com.infosec.asn1.nist.NISTNamedCurves;
import cn.com.infosec.asn1.sec.SECNamedCurves;
import cn.com.infosec.asn1.teletrust.TeleTrusTNamedCurves;
import cn.com.infosec.asn1.x9.X962NamedCurves;
import cn.com.infosec.asn1.x9.X9ECParameters;
import cn.com.infosec.crypto.AsymmetricCipherKeyPair;
import cn.com.infosec.crypto.generators.DHBasicKeyPairGenerator;
import cn.com.infosec.crypto.generators.DHParametersGenerator;
import cn.com.infosec.crypto.generators.DSAKeyPairGenerator;
import cn.com.infosec.crypto.generators.DSAParametersGenerator;
import cn.com.infosec.crypto.generators.ECKeyPairGenerator;
import cn.com.infosec.crypto.generators.ElGamalKeyPairGenerator;
import cn.com.infosec.crypto.generators.ElGamalParametersGenerator;
import cn.com.infosec.crypto.generators.GOST3410KeyPairGenerator;
import cn.com.infosec.crypto.generators.RSAKeyPairGenerator;
import cn.com.infosec.crypto.params.DHKeyGenerationParameters;
import cn.com.infosec.crypto.params.DHParameters;
import cn.com.infosec.crypto.params.DHPrivateKeyParameters;
import cn.com.infosec.crypto.params.DHPublicKeyParameters;
import cn.com.infosec.crypto.params.DSAKeyGenerationParameters;
import cn.com.infosec.crypto.params.DSAParameters;
import cn.com.infosec.crypto.params.DSAPrivateKeyParameters;
import cn.com.infosec.crypto.params.DSAPublicKeyParameters;
import cn.com.infosec.crypto.params.ECDomainParameters;
import cn.com.infosec.crypto.params.ECKeyGenerationParameters;
import cn.com.infosec.crypto.params.ECPrivateKeyParameters;
import cn.com.infosec.crypto.params.ECPublicKeyParameters;
import cn.com.infosec.crypto.params.ElGamalKeyGenerationParameters;
import cn.com.infosec.crypto.params.ElGamalParameters;
import cn.com.infosec.crypto.params.ElGamalPrivateKeyParameters;
import cn.com.infosec.crypto.params.ElGamalPublicKeyParameters;
import cn.com.infosec.crypto.params.GOST3410KeyGenerationParameters;
import cn.com.infosec.crypto.params.GOST3410Parameters;
import cn.com.infosec.crypto.params.GOST3410PrivateKeyParameters;
import cn.com.infosec.crypto.params.GOST3410PublicKeyParameters;
import cn.com.infosec.crypto.params.RSAKeyGenerationParameters;
import cn.com.infosec.crypto.params.RSAKeyParameters;
import cn.com.infosec.crypto.params.RSAPrivateCrtKeyParameters;
import cn.com.infosec.jce.spec.ECNamedCurveSpec;
import cn.com.infosec.jce.spec.ECParameterSpec;
import cn.com.infosec.jce.spec.ElGamalParameterSpec;
import cn.com.infosec.jce.spec.GOST3410ParameterSpec;
import cn.com.infosec.jce.spec.GOST3410PublicKeyParameterSetSpec;
import cn.com.infosec.math.ec.ECCurve;
import cn.com.infosec.math.ec.ECPoint;
import java.math.BigInteger;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidParameterException;
import java.security.KeyPair;
import java.security.KeyPairGenerator;
import java.security.SecureRandom;
import java.security.spec.AlgorithmParameterSpec;
import java.security.spec.DSAParameterSpec;
import java.security.spec.ECGenParameterSpec;
import java.security.spec.RSAKeyGenParameterSpec;
import java.util.Hashtable;
import javax.crypto.spec.DHParameterSpec;

public abstract class JDKKeyPairGenerator extends KeyPairGenerator {
   public JDKKeyPairGenerator(String algorithmName) {
      super(algorithmName);
   }

   public abstract void initialize(int var1, SecureRandom var2);

   public abstract KeyPair generateKeyPair();

   public static class DH extends JDKKeyPairGenerator {
      DHKeyGenerationParameters param;
      DHBasicKeyPairGenerator engine;
      int strength;
      int certainty;
      SecureRandom random;
      boolean initialised;

      public DH() {
         DH var10000 = this;
         DH var10001 = this;
         DH var10002 = this;
         DH var10003 = this;
         DH var10004 = this;
         super("DH");
         DHBasicKeyPairGenerator var1;
         var1 = new DHBasicKeyPairGenerator.<init>();
         var10004.engine = var1;
         var10003.strength = 1024;
         var10002.certainty = 20;
         SecureRandom var2;
         var2 = new SecureRandom.<init>();
         var10001.random = var2;
         var10000.initialised = false;
      }

      public void initialize(int strength, SecureRandom random) {
         this.strength = strength;
         this.random = random;
      }

      public void initialize(AlgorithmParameterSpec params, SecureRandom random) {
         if (params instanceof DHParameterSpec) {
            DH var10000 = this;
            DH var10001 = this;
            DH var10002 = this;
            DHParameterSpec var5 = (DHParameterSpec)params;
            DHKeyGenerationParameters params1;
            DHKeyGenerationParameters var10003 = params1 = new DHKeyGenerationParameters;
            SecureRandom var10005 = random;
            DHParameters random1;
            DHParameters var10006 = random1 = new DHParameters;
            DHParameterSpec var10007 = var5;
            DHParameterSpec var10008 = var5;
            BigInteger var6 = var5.getP();
            BigInteger var3 = var10008.getG();
            int var4 = var10007.getL();
            var10006.<init>(var6, var3, (BigInteger)null, var4);
            var10003.<init>(var10005, random1);
            var10002.param = var10003;
            var10001.engine.init(params1);
            var10000.initialised = true;
         } else {
            throw new InvalidAlgorithmParameterException("parameter object not a DHParameterSpec");
         }
      }

      public KeyPair generateKeyPair() {
         if (!this.initialised) {
            DHParametersGenerator var1;
            DHParametersGenerator var10003 = var1 = new DHParametersGenerator;
            var1.<init>();
            int var2 = this.strength;
            int var3 = this.certainty;
            SecureRandom var4 = this.random;
            var10003.init(var2, var3, var4);
            DHKeyGenerationParameters var9;
            DHKeyGenerationParameters var10 = var9 = new DHKeyGenerationParameters;
            DHParametersGenerator var10005 = var1;
            SecureRandom var7 = this.random;
            var10.<init>(var7, var10005.generateParameters());
            this.param = var10;
            this.engine.init(var9);
            this.initialised = true;
         }

         AsymmetricCipherKeyPair var10000 = this.engine.generateKeyPair();
         DHPublicKeyParameters var5 = (DHPublicKeyParameters)var10000.getPublic();
         DHPrivateKeyParameters var8 = (DHPrivateKeyParameters)var10000.getPrivate();
         JCEDHPublicKey var10002 = new JCEDHPublicKey(var5);
         JCEDHPrivateKey var6;
         var6 = new JCEDHPrivateKey.<init>(var8);
         return new KeyPair(var10002, var6);
      }
   }

   public static class DSA extends JDKKeyPairGenerator {
      DSAKeyGenerationParameters param;
      DSAKeyPairGenerator engine;
      int strength;
      int certainty;
      SecureRandom random;
      boolean initialised;

      public DSA() {
         DSA var10000 = this;
         DSA var10001 = this;
         DSA var10002 = this;
         DSA var10003 = this;
         DSA var10004 = this;
         super("DSA");
         DSAKeyPairGenerator var1;
         var1 = new DSAKeyPairGenerator.<init>();
         var10004.engine = var1;
         var10003.strength = 1024;
         var10002.certainty = 20;
         SecureRandom var2;
         var2 = new SecureRandom.<init>();
         var10001.random = var2;
         var10000.initialised = false;
      }

      public void initialize(int strength, SecureRandom random) {
         if (strength >= 512 && strength <= 1024 && strength % 64 == 0) {
            this.strength = strength;
            this.random = random;
         } else {
            throw new InvalidParameterException("strength must be from 512 - 1024 and a multiple of 64");
         }
      }

      public void initialize(AlgorithmParameterSpec params, SecureRandom random) {
         if (params instanceof DSAParameterSpec) {
            DSA var10000 = this;
            DSA var10001 = this;
            DSA var10002 = this;
            DSAParameterSpec var5 = (DSAParameterSpec)params;
            DSAKeyGenerationParameters params1;
            DSAKeyGenerationParameters var10003 = params1 = new DSAKeyGenerationParameters;
            SecureRandom var10005 = random;
            DSAParameters random1;
            DSAParameters var10006 = random1 = new DSAParameters;
            DSAParameterSpec var10007 = var5;
            DSAParameterSpec var10008 = var5;
            BigInteger var6 = var5.getP();
            BigInteger var3 = var10008.getQ();
            BigInteger var4 = var10007.getG();
            var10006.<init>(var6, var3, var4);
            var10003.<init>(var10005, random1);
            var10002.param = var10003;
            var10001.engine.init(params1);
            var10000.initialised = true;
         } else {
            throw new InvalidAlgorithmParameterException("parameter object not a DSAParameterSpec");
         }
      }

      public KeyPair generateKeyPair() {
         if (!this.initialised) {
            DSAParametersGenerator var1;
            DSAParametersGenerator var10003 = var1 = new DSAParametersGenerator;
            var1.<init>();
            int var2 = this.strength;
            int var3 = this.certainty;
            SecureRandom var4 = this.random;
            var10003.init(var2, var3, var4);
            DSAKeyGenerationParameters var9;
            DSAKeyGenerationParameters var10 = var9 = new DSAKeyGenerationParameters;
            DSAParametersGenerator var10005 = var1;
            SecureRandom var7 = this.random;
            var10.<init>(var7, var10005.generateParameters());
            this.param = var10;
            this.engine.init(var9);
            this.initialised = true;
         }

         AsymmetricCipherKeyPair var10000 = this.engine.generateKeyPair();
         DSAPublicKeyParameters var5 = (DSAPublicKeyParameters)var10000.getPublic();
         DSAPrivateKeyParameters var8 = (DSAPrivateKeyParameters)var10000.getPrivate();
         JDKDSAPublicKey var10002 = new JDKDSAPublicKey(var5);
         JDKDSAPrivateKey var6;
         var6 = new JDKDSAPrivateKey.<init>(var8);
         return new KeyPair(var10002, var6);
      }
   }

   public static class EC extends JDKKeyPairGenerator {
      private static Hashtable ecParameters;
      ECKeyGenerationParameters param;
      ECKeyPairGenerator engine;
      Object ecParams;
      int strength;
      int certainty;
      SecureRandom random;
      boolean initialised;
      String algorithm;

      static {
         Hashtable var10000 = ecParameters = new Hashtable();
         Integer var10001 = new Integer(192);
         ECGenParameterSpec var0;
         var0 = new ECGenParameterSpec.<init>("prime192v1");
         var10000.put(var10001, var0);
         var10000 = ecParameters;
         var10001 = new Integer(239);
         var0 = new ECGenParameterSpec.<init>("prime239v1");
         var10000.put(var10001, var0);
         var10000 = ecParameters;
         var10001 = new Integer(256);
         var0 = new ECGenParameterSpec.<init>("prime256v1");
         var10000.put(var10001, var0);
      }

      public EC() {
         EC var10000 = this;
         EC var10001 = this;
         EC var10002 = this;
         EC var10003 = this;
         EC var10004 = this;
         EC var10005 = this;
         EC var10006 = this;
         super("EC");
         ECKeyPairGenerator var1;
         var1 = new ECKeyPairGenerator.<init>();
         var10006.engine = var1;
         var10005.ecParams = null;
         var10004.strength = 239;
         var10003.certainty = 50;
         SecureRandom var2;
         var2 = new SecureRandom.<init>();
         var10002.random = var2;
         var10001.initialised = false;
         var10000.algorithm = "EC";
      }

      public EC(String algorithm) {
         EC var10000 = this;
         EC var10001 = this;
         EC var10002 = this;
         EC var10003 = this;
         EC var10004 = this;
         EC var10005 = this;
         EC var10006 = this;
         super(algorithm);
         ECKeyPairGenerator var2;
         var2 = new ECKeyPairGenerator.<init>();
         var10006.engine = var2;
         var10005.ecParams = null;
         var10004.strength = 239;
         var10003.certainty = 50;
         SecureRandom var3;
         var3 = new SecureRandom.<init>();
         var10002.random = var3;
         var10001.initialised = false;
         var10000.algorithm = algorithm;
      }

      public void initialize(int strength, SecureRandom random) {
         this.strength = strength;
         this.random = random;
         Object strength1;
         Object var10000 = strength1 = ecParameters.get(new Integer(strength));
         this.ecParams = strength1;
         if (var10000 != null) {
            try {
               this.initialize((ECGenParameterSpec)strength1, random);
            } catch (InvalidAlgorithmParameterException var3) {
               throw new InvalidParameterException("key size not configurable.");
            }
         } else {
            throw new InvalidParameterException("unknown key size.");
         }
      }

      public void initialize(AlgorithmParameterSpec params, SecureRandom random) {
         ECPoint var3;
         BigInteger var4;
         ECParameterSpec var9;
         ECCurve var10;
         ECKeyGenerationParameters params1;
         EC var10000;
         EC var10001;
         EC var10002;
         EC var10003;
         ECParameterSpec var10007;
         ECParameterSpec var10008;
         ECKeyGenerationParameters var26;
         if (params instanceof ECParameterSpec) {
            var10000 = this;
            var10001 = this;
            var10002 = this;
            var10003 = this;
            var9 = (ECParameterSpec)params;
            var10003.ecParams = params;
            var26 = params1 = new ECKeyGenerationParameters;
            var10007 = var9;
            var10008 = var9;
            var10 = var9.getCurve();
            var3 = var10008.getG();
            var4 = var10007.getN();
            var26.<init>(new ECDomainParameters(var10, var3, var4), random);
            var10002.param = var26;
            var10001.engine.init(params1);
            var10000.initialised = true;
         } else {
            java.security.spec.ECParameterSpec var11;
            BigInteger var13;
            ECCurve params4;
            BigInteger params5;
            ECKeyGenerationParameters var22;
            ECCurve var31;
            java.security.spec.ECParameterSpec var32;
            if (params instanceof java.security.spec.ECParameterSpec) {
               var10000 = this;
               var10001 = this;
               var10002 = this;
               var10003 = this;
               var11 = (java.security.spec.ECParameterSpec)params;
               var10003.ecParams = params;
               var3 = EC5Util.convertPoint(params4 = EC5Util.convertCurve(var11.getCurve()), var11.getGenerator(), false);
               var26 = var22 = new ECKeyGenerationParameters;
               var31 = params4;
               var32 = var11;
               var13 = var11.getOrder();
               params5 = BigInteger.valueOf((long)var32.getCofactor());
               var26.<init>(new ECDomainParameters(var31, var3, var13, params5), random);
               var10002.param = var26;
               var10001.engine.init(var22);
               var10000.initialised = true;
            } else if (params instanceof ECGenParameterSpec) {
               ECPoint var5;
               BigInteger var6;
               BigInteger var7;
               byte[] var8;
               ECGenParameterSpec params2;
               String params3;
               ECCurve var19;
               ECNamedCurveSpec var21;
               ECNamedCurveSpec var23;
               if (this.algorithm.equals("ECGOST3410")) {
                  ECDomainParameters var17;
                  if ((var17 = ECGOST3410NamedCurves.getByName((params2 = (ECGenParameterSpec)params).getName())) == null) {
                     throw new InvalidAlgorithmParameterException("unknown curve name: " + params2.getName());
                  }

                  var23 = var21 = new ECNamedCurveSpec;
                  ECDomainParameters var24 = var17;
                  ECDomainParameters var27 = var17;
                  ECDomainParameters var10004 = var17;
                  ECDomainParameters var10005 = var17;
                  params3 = params2.getName();
                  var19 = var17.getCurve();
                  var5 = var10005.getG();
                  var6 = var10004.getN();
                  var7 = var27.getH();
                  var8 = var24.getSeed();
                  var23.<init>(params3, var19, var5, var6, var7, var8);
                  this.ecParams = var21;
               } else {
                  X9ECParameters var20;
                  if ((var20 = X962NamedCurves.getByName((params2 = (ECGenParameterSpec)params).getName())) == null) {
                     if ((var20 = SECNamedCurves.getByName(params2.getName())) == null) {
                        var20 = NISTNamedCurves.getByName(params2.getName());
                     }

                     if (var20 == null) {
                        var20 = TeleTrusTNamedCurves.getByName(params2.getName());
                     }

                     if (var20 == null) {
                        throw new InvalidAlgorithmParameterException("unknown curve name: " + params2.getName());
                     }
                  }

                  var23 = var21 = new ECNamedCurveSpec;
                  X9ECParameters var25 = var20;
                  X9ECParameters var28 = var20;
                  X9ECParameters var29 = var20;
                  X9ECParameters var30 = var20;
                  params3 = params2.getName();
                  var19 = var20.getCurve();
                  var5 = var30.getG();
                  var6 = var29.getN();
                  var7 = var28.getH();
                  var8 = var25.getSeed();
                  var23.<init>(params3, var19, var5, var6, var7, var8);
                  this.ecParams = var21;
               }

               var10000 = this;
               var10001 = this;
               var10002 = this;
               var3 = EC5Util.convertPoint(params4 = EC5Util.convertCurve((var11 = (java.security.spec.ECParameterSpec)this.ecParams).getCurve()), var11.getGenerator(), false);
               var26 = var22 = new ECKeyGenerationParameters;
               var31 = params4;
               var32 = var11;
               var13 = var11.getOrder();
               params5 = BigInteger.valueOf((long)var32.getCofactor());
               var26.<init>(new ECDomainParameters(var31, var3, var13, params5), random);
               var10002.param = var26;
               var10001.engine.init(var22);
               var10000.initialised = true;
            } else {
               if (params != null || ProviderUtil.getEcImplicitlyCa() == null) {
                  if (params == null && ProviderUtil.getEcImplicitlyCa() == null) {
                     throw new InvalidAlgorithmParameterException("null parameter passed by no implicitCA set");
                  }

                  throw new InvalidAlgorithmParameterException("parameter object not a ECParameterSpec");
               }

               var10000 = this;
               var10001 = this;
               var10002 = this;
               var10003 = this;
               var9 = ProviderUtil.getEcImplicitlyCa();
               var10003.ecParams = params;
               var26 = params1 = new ECKeyGenerationParameters;
               var10007 = var9;
               var10008 = var9;
               var10 = var9.getCurve();
               var3 = var10008.getG();
               var4 = var10007.getN();
               var26.<init>(new ECDomainParameters(var10, var3, var4), random);
               var10002.param = var26;
               var10001.engine.init(params1);
               var10000.initialised = true;
            }
         }

      }

      public KeyPair generateKeyPair() {
         if (this.initialised) {
            AsymmetricCipherKeyPair var10001 = this.engine.generateKeyPair();
            ECPublicKeyParameters var1 = (ECPublicKeyParameters)var10001.getPublic();
            ECPrivateKeyParameters var2 = (ECPrivateKeyParameters)var10001.getPrivate();
            JCEECPublicKey var10002;
            Object var3;
            JCEECPrivateKey var4;
            if ((var3 = this.ecParams) instanceof ECParameterSpec) {
               ECParameterSpec var6 = (ECParameterSpec)var3;
               var10002 = new JCEECPublicKey(this.algorithm, var1, var6);
               var4 = new JCEECPrivateKey.<init>(this.algorithm, var2, var6);
               return new KeyPair(var10002, var4);
            } else if (var3 == null) {
               var10002 = new JCEECPublicKey(this.algorithm, var1);
               var4 = new JCEECPrivateKey.<init>(this.algorithm, var2);
               return new KeyPair(var10002, var4);
            } else {
               java.security.spec.ECParameterSpec var5 = (java.security.spec.ECParameterSpec)var3;
               var10002 = new JCEECPublicKey(this.algorithm, var1, var5);
               var4 = new JCEECPrivateKey.<init>(this.algorithm, var2, var5);
               return new KeyPair(var10002, var4);
            }
         } else {
            throw new IllegalStateException("EC Key Pair Generator not initialised");
         }
      }
   }

   public static class ECDH extends EC {
      public ECDH() {
         super("ECDH");
      }
   }

   public static class ECDHC extends EC {
      public ECDHC() {
         super("ECDHC");
      }
   }

   public static class ECDSA extends EC {
      public ECDSA() {
         super("ECDSA");
      }
   }

   public static class ECGOST3410 extends EC {
      public ECGOST3410() {
         super("ECGOST3410");
      }
   }

   public static class ElGamal extends JDKKeyPairGenerator {
      ElGamalKeyGenerationParameters param;
      ElGamalKeyPairGenerator engine;
      int strength;
      int certainty;
      SecureRandom random;
      boolean initialised;

      public ElGamal() {
         ElGamal var10000 = this;
         ElGamal var10001 = this;
         ElGamal var10002 = this;
         ElGamal var10003 = this;
         ElGamal var10004 = this;
         super("ElGamal");
         ElGamalKeyPairGenerator var1;
         var1 = new ElGamalKeyPairGenerator.<init>();
         var10004.engine = var1;
         var10003.strength = 1024;
         var10002.certainty = 20;
         SecureRandom var2;
         var2 = new SecureRandom.<init>();
         var10001.random = var2;
         var10000.initialised = false;
      }

      public void initialize(int strength, SecureRandom random) {
         this.strength = strength;
         this.random = random;
      }

      public void initialize(AlgorithmParameterSpec params, SecureRandom random) {
         boolean var3;
         if (!(var3 = params instanceof ElGamalParameterSpec) && !(params instanceof DHParameterSpec)) {
            throw new InvalidAlgorithmParameterException("parameter object not a DHParameterSpec or an ElGamalParameterSpec");
         } else {
            ElGamalParameters var4;
            BigInteger params2;
            ElGamalKeyGenerationParameters var10;
            ElGamalKeyGenerationParameters var10001;
            ElGamalParameters var10002;
            if (var3) {
               ElGamalParameterSpec params1 = (ElGamalParameterSpec)params;
               var10001 = var10 = new ElGamalKeyGenerationParameters;
               var10002 = var4 = new ElGamalParameters;
               ElGamalParameterSpec var10003 = params1;
               params2 = params1.getP();
               var10002.<init>(params2, var10003.getG());
               var10001.<init>(random, var4);
               this.param = var10;
            } else {
               DHParameterSpec params3 = (DHParameterSpec)params;
               var10001 = var10 = new ElGamalKeyGenerationParameters;
               var10002 = var4 = new ElGamalParameters;
               DHParameterSpec var11 = params3;
               DHParameterSpec var10004 = params3;
               params2 = params3.getP();
               BigInteger var5 = var10004.getG();
               int var6 = var11.getL();
               var10002.<init>(params2, var5, var6);
               var10001.<init>(random, var4);
               this.param = var10;
            }

            this.engine.init(this.param);
            this.initialised = true;
         }
      }

      public KeyPair generateKeyPair() {
         if (!this.initialised) {
            ElGamalParametersGenerator var1;
            ElGamalParametersGenerator var10003 = var1 = new ElGamalParametersGenerator;
            var1.<init>();
            int var2 = this.strength;
            int var3 = this.certainty;
            SecureRandom var4 = this.random;
            var10003.init(var2, var3, var4);
            ElGamalKeyGenerationParameters var9;
            ElGamalKeyGenerationParameters var10 = var9 = new ElGamalKeyGenerationParameters;
            ElGamalParametersGenerator var10005 = var1;
            SecureRandom var7 = this.random;
            var10.<init>(var7, var10005.generateParameters());
            this.param = var10;
            this.engine.init(var9);
            this.initialised = true;
         }

         AsymmetricCipherKeyPair var10000 = this.engine.generateKeyPair();
         ElGamalPublicKeyParameters var5 = (ElGamalPublicKeyParameters)var10000.getPublic();
         ElGamalPrivateKeyParameters var8 = (ElGamalPrivateKeyParameters)var10000.getPrivate();
         JCEElGamalPublicKey var10002 = new JCEElGamalPublicKey(var5);
         JCEElGamalPrivateKey var6;
         var6 = new JCEElGamalPrivateKey.<init>(var8);
         return new KeyPair(var10002, var6);
      }
   }

   public static class GOST3410 extends JDKKeyPairGenerator {
      GOST3410KeyGenerationParameters param;
      GOST3410KeyPairGenerator engine;
      GOST3410ParameterSpec gost3410Params;
      int strength;
      SecureRandom random;
      boolean initialised;

      public GOST3410() {
         GOST3410 var10000 = this;
         GOST3410 var10001 = this;
         GOST3410 var10002 = this;
         GOST3410 var10003 = this;
         super("GOST3410");
         GOST3410KeyPairGenerator var1;
         var1 = new GOST3410KeyPairGenerator.<init>();
         var10003.engine = var1;
         var10002.strength = 1024;
         var10001.random = null;
         var10000.initialised = false;
      }

      private void init(GOST3410ParameterSpec gParams, SecureRandom random) {
         GOST3410 var10000 = this;
         GOST3410ParameterSpec var10001 = gParams;
         GOST3410 var10002 = this;
         GOST3410 var10003 = this;
         GOST3410 var10004 = this;
         GOST3410PublicKeyParameterSetSpec var5 = gParams.getPublicKeyParameters();
         GOST3410KeyGenerationParameters gParams1;
         GOST3410KeyGenerationParameters var10005 = gParams1 = new GOST3410KeyGenerationParameters;
         SecureRandom var10007 = random;
         GOST3410Parameters random1;
         GOST3410Parameters var10008 = random1 = new GOST3410Parameters;
         GOST3410PublicKeyParameterSetSpec var10009 = var5;
         GOST3410PublicKeyParameterSetSpec var10010 = var5;
         BigInteger var6 = var5.getP();
         BigInteger var3 = var10010.getQ();
         BigInteger var4 = var10009.getA();
         var10008.<init>(var6, var3, var4);
         var10005.<init>(var10007, random1);
         var10004.param = var10005;
         var10003.engine.init(gParams1);
         var10002.initialised = true;
         var10000.gost3410Params = var10001;
      }

      public void initialize(int strength, SecureRandom random) {
         this.strength = strength;
         this.random = random;
      }

      public void initialize(AlgorithmParameterSpec params, SecureRandom random) {
         if (params instanceof GOST3410ParameterSpec) {
            this.init((GOST3410ParameterSpec)params, random);
         } else {
            throw new InvalidAlgorithmParameterException("parameter object not a GOST3410ParameterSpec");
         }
      }

      public KeyPair generateKeyPair() {
         if (!this.initialised) {
            GOST3410ParameterSpec var10001 = new GOST3410ParameterSpec(CryptoProObjectIdentifiers.gostR3410_94_CryptoPro_A.getId());
            SecureRandom var1;
            var1 = new SecureRandom.<init>();
            this.init(var10001, var1);
         }

         AsymmetricCipherKeyPair var10000 = this.engine.generateKeyPair();
         GOST3410PublicKeyParameters var3 = (GOST3410PublicKeyParameters)var10000.getPublic();
         GOST3410PrivateKeyParameters var2 = (GOST3410PrivateKeyParameters)var10000.getPrivate();
         return new KeyPair(new JDKGOST3410PublicKey(var3, this.gost3410Params), new JDKGOST3410PrivateKey(var2, this.gost3410Params));
      }
   }

   public static class RSA extends JDKKeyPairGenerator {
      static final BigInteger defaultPublicExponent = BigInteger.valueOf(65537L);
      static final int defaultTests = 12;
      RSAKeyGenerationParameters param;
      RSAKeyPairGenerator engine;

      public RSA() {
         RSA var10000 = this;
         RSA var10001 = this;
         super("RSA");
         this.engine = new RSAKeyPairGenerator();
         RSAKeyGenerationParameters var1;
         RSAKeyGenerationParameters var10002 = var1 = new RSAKeyGenerationParameters;
         var10002.<init>(defaultPublicExponent, new SecureRandom(), 2048, 12);
         var10001.param = var10002;
         var10000.engine.init(var1);
      }

      public void initialize(int strength, SecureRandom random) {
         RSA var10000 = this;
         RSA var10001 = this;
         RSAKeyGenerationParameters var3;
         RSAKeyGenerationParameters var10002 = var3 = new RSAKeyGenerationParameters;
         var10002.<init>(defaultPublicExponent, random, strength, 12);
         var10001.param = var10002;
         var10000.engine.init(var3);
      }

      public void initialize(AlgorithmParameterSpec params, SecureRandom random) {
         if (params instanceof RSAKeyGenParameterSpec) {
            RSA var10000 = this;
            RSA var10001 = this;
            RSAKeyGenParameterSpec var4 = (RSAKeyGenParameterSpec)params;
            RSAKeyGenerationParameters params1;
            RSAKeyGenerationParameters var10002 = params1 = new RSAKeyGenerationParameters;
            RSAKeyGenParameterSpec var10004 = var4;
            BigInteger var5 = var4.getPublicExponent();
            int var3 = var10004.getKeysize();
            var10002.<init>(var5, random, var3, 12);
            var10001.param = var10002;
            var10000.engine.init(params1);
         } else {
            throw new InvalidAlgorithmParameterException("parameter object not a RSAKeyGenParameterSpec");
         }
      }

      public KeyPair generateKeyPair() {
         AsymmetricCipherKeyPair var10000 = this.engine.generateKeyPair();
         RSAKeyParameters var2 = (RSAKeyParameters)var10000.getPublic();
         RSAPrivateCrtKeyParameters var1 = (RSAPrivateCrtKeyParameters)var10000.getPrivate();
         JCERSAPublicKey var10002 = new JCERSAPublicKey(var2);
         JCERSAPrivateCrtKey var3;
         var3 = new JCERSAPrivateCrtKey.<init>(var1);
         return new KeyPair(var10002, var3);
      }
   }
}
